@@ -56,7 +56,7 @@
 #' "sum" the considered daily_dose is the sum of all the exposures present in
 #' the subexposure.
 #' @param sameIndexMode How the overlapping between two exposures that start on
-#' the same day is solved inside a subexposure. There are five possible options:
+#' the same day is solved inside a subexposure. There are three possible options:
 #' "minimum" the considered daily_dose is the minimum of all of the exposures in
 #' the subexposure.
 #' "maximum" the considered daily_dose is the maximum of all of the exposures in
@@ -69,12 +69,12 @@
 #' "none", "median", "mean", "mode" or a number
 #' @param durationRange Range between the duration must be comprised. It should
 #' be a numeric vector of length two, with no NAs and the first value should be
-#' equal or smaller than the second one. It is only required if imputeDuration
-#' = TRUE. If NULL no restrictions are applied.
+#' equal or smaller than the second one. It must not be NULL if imputeDuration
+#' is not "none". If NULL no restrictions are applied.
 #' @param dailyDoseRange Range between the daily_dose must be comprised. It
 #' should be a numeric vector of length two, with no NAs and the first value
-#' should be equal or smaller than the second one. It is only required if
-#' imputeDailyDose = TRUE. If NULL no restrictions are applied.
+#' should be equal or smaller than the second one. It must not be NULL if
+#' imputeDailyDose is not "none". If NULL no restrictions are applied.
 #'
 #' @return The same cohort with the added columns.
 #'
@@ -210,7 +210,7 @@ addDrugUse <- function(cohort,
     # add daily dose
     cohortInfo <- cohortInfo %>%
       addDailyDose(ingredientConceptId = ingredientConceptId) %>%
-      dplyr::select(-"quantity", -"route") %>%
+      dplyr::select(-"quantity") %>%
       dplyr::distinct()
 
     # impute daily dose
@@ -508,13 +508,13 @@ initialSubset <- function(cdm, dusCohort, conceptSet) {
       by = "drug_concept_id",
       copy = TRUE
     ) %>%
-    dplyr::mutate(drug_exposure_end_date = dplyr::if_else(
-      is.na(.data$drug_exposure_end_date),
-      .data$drug_exposure_start_date,
-      .data$drug_exposure_end_date
-    )) %>%
-    dplyr::filter(.data$drug_exposure_start_date <= .data$cohort_end_date) %>%
-    dplyr::filter(.data$drug_exposure_end_date >= .data$cohort_start_date) %>%
+    dplyr::filter(
+      (is.na(.data$drug_exposure_end_date) &
+         (.data$drug_exposure_start_date <= .data$cohort_end_date)) |
+        (!is.na(.data$drug_exposure_end_date) &
+           ((.data$drug_exposure_end_date >= .data$cohort_start_date) &
+           (.data$drug_exposure_start_date <= .data$cohort_end_date)))
+    ) %>%
     CDMConnector::computeQuery(
       temporary = FALSE, schema = attr(cdm, "write_schema"),
       overwrite = TRUE
@@ -1002,10 +1002,7 @@ addImpute <- function(cohort, cohortInfo, imputeCount, label) {
             .groups = "drop"
           ),
         by = c("subject_id", "cohort_start_date", "cohort_end_date")
-      ) %>%
-      dplyr::mutate(!!label := dplyr::if_else(
-        is.na(.data[[label]]), 0, .data[[label]]
-      ))
+      )
   }
   return(cohort)
 }
