@@ -20,9 +20,8 @@
 #' @param cohort Cohort with indications and strata
 #' @param cdm cdm_reference created by CDMConnector
 #' @param strata Stratification list
-#' @param indicationVariables Variables that point to an indication column
 #' @param minCellCount Minimum counts that a group can have. Cohorts with
-#' less counts than this value are obscured. By default: 5.
+#' less counts than this value are obscured.
 #'
 #' @return A Tibble with 4 columns: cohort_definition_id, variable, estimate and
 #' value. There will be one row for each cohort, variable and cohort
@@ -41,47 +40,67 @@
 #' cdm <- generateConceptCohortSet(cdm, indications, "indication_cohorts")
 #' acetaminophen <- getDrugIngredientCodes(cdm, "acetaminophen")
 #' cdm <- generateDrugUtilisationCohortSet(cdm, "drug_cohort", acetaminophen)
-#' cdm$drug_cohort <- cdm$drug_cohort %>%
+#' cdm[["drug_cohort"]] <- cdm[["drug_cohort"]] %>%
 #'   addIndication(cdm, "indication_cohorts", indicationGap = c(0, 30, 365))
 #'
-#' summariseIndication(cdm$drug_cohort, cdm)
+#' summariseIndication(cdm[["drug_cohort"]], cdm)
 #'
-#' cdm$drug_cohort <- cdm$drug_cohort %>%
+#' cdm[["drug_cohort"]] <- cdm[["drug_cohort"]] %>%
 #'   addAge(cdm, ageGroup = list("<40" = c(0, 39), ">=40" = c(40, 150))) %>%
 #'   addSex(cdm)
 #'
 #' summariseIndication(
-#'   cdm$drug_cohort, cdm, strata = list(
+#'   cdm[["drug_cohort"]], cdm, strata = list(
 #'     "age_group" = "age_group", "age_group and sex" = c("age_group", "sex")
 #'   )
 #' )
 #' }
 #'
 summariseIndication <- function(cohort,
-                                cdm,
+                                cdm = attr(cohort, "cdm_reference"),
                                 strata = list(),
-                                indicationVariables = indicationColumns(cohort),
-                                minCellCount = 1) {
+                                minCellCount = 5) {
   # initialChecks
   checkInputs(
-    cohort = cohort, cdm = cdm, strata = strata,
-    indicationVariables = indicationVariables, minCellCount = minCellCount
+    cohort = cohort, cdm = cdm, strata = strata, minCellCount = minCellCount
   )
 
+  indicationVariables <- indicationColumns(cohort)
+
   # update cohort_names
-  cohort <- cohort %>%
-    dplyr::left_join(
-      CDMConnector::cohortSet(cohort), by = "cohort_definition_id", copy = TRUE
-    )
+  cohort <- cohort %>% PatientProfiles::addCohortName() %>% dplyr::collect()
 
   # summarise indication columns
   result <- PatientProfiles::summariseResult(
     table = cohort, group = list("cohort_name" = "cohort_name"),
-    strata = strata, variables = list(binary = indicationVariables),
-    functions = list(binary = c("count")),# to add percentage
+    strata = strata, variables = indicationVariables,
+    functions = c("count", "percentage"),
     minCellCount = minCellCount
   ) %>%
     dplyr::mutate(
+      variable_level = dplyr::if_else(
+        substr(.data$variable, 1, 15) == "indication_gap_",
+        lapply(strsplit(.data$variable, "_"), function(x) {
+          if (length(x) > 3) {
+            x <- paste0(x[-c(1:3)], collapse = "_")
+            x <- paste0(toupper(substr(x, 1, 1)), substr(x, 2, nchar(x)))
+          } else {
+            x<- as.character(NA)
+          }
+          return(x)
+        }) %>%
+          unlist(),
+        as.character(NA)
+      ),
+      variable = dplyr::if_else(
+        substr(.data$variable, 1, 15) == "indication_gap_",
+        lapply(strsplit(.data$variable, "_"), function(x) {
+          x <- paste0(x[1:min(3, length(x))], collapse = "_")
+          x <- indicationColumnName(x)
+        }) %>%
+          unlist(),
+        .data$variable
+      ),
       cdm_name = dplyr::coalesce(CDMConnector::cdmName(cdm), as.character(NA)),
       result_type = "Summary indication"
     )
@@ -95,25 +114,20 @@ summariseIndication <- function(cohort,
 #'
 #' @return Name of the indication columns
 #'
-#' @export
-#'
-#' @examples
-#' \donttest{
-#' library(DrugUtilisation)
-#' library(CodelistGenerator)
-#'
-#' cdm <- mockDrugUtilisation()
-#' indications <- list("headache" = 378253, "asthma" = 317009)
-#' cdm <- generateConceptCohortSet(cdm, indications, "indication_cohorts")
-#' acetaminophen <- getDrugIngredientCodes(cdm, "acetaminophen")
-#' cdm <- generateDrugUtilisationCohortSet(cdm, "drug_cohort", acetaminophen)
-#' cdm$drug_cohort <- cdm$drug_cohort %>%
-#'   addIndication(cdm, "indication_cohorts", indicationGap = c(0, 30, 365))
-#'
-#' indicationColumns(cdm$drug_cohort)
-#' }
+#' @noRd
 #'
 indicationColumns <- function(x) {
   names <- colnames(x)[substr(colnames(x), 1, 15) == "indication_gap_"]
   return(names)
 }
+
+indicationColumnName <- function(x) {
+  x[x == "indication_gap_0"] <- "Indication on index date"
+  x[x == "indication_gap_inf"] <- "Indication any time prior"
+  id <- substr(x, 1, 15) == "indication_gap_"
+  y <- x[id]
+  x[id] <- paste(
+    "Indication during prior", substr(x[id], 16, nchar(x[id])), "days"
+  )
+  return(x)
+}
